#!/bin/bash

echo "Installing Encrypted Password Database DB for Linux"

RHEL_VERSION=0

# Check for rhel6
/bin/cat /etc/redhat-release | grep -i Santiago >/dev/null 2>&1
if [ $? -eq 0 ]; then RHEL_VERSION=6; fi

# Check for rhel7
/bin/cat /etc/redhat-release | grep -i Maipo >/dev/null 2>&1
if [ $? -eq 0 ]; then RHEL_VERSION=7; fi

# Check for rhel8
/bin/cat /etc/redhat-release | grep -i Ootpa >/dev/null 2>&1
if [ $? -eq 0 ]; then RHEL_VERSION=8; fi

# Check for rhel9
/bin/cat /etc/redhat-release | grep -i Plow >/dev/null 2>&1
if [ $? -eq 0 ]; then RHEL_VERSION=9; fi


if [ ! -d ${HOME}/.encrypted_password_database ]; then
    mkdir -pv ${HOME}/.encrypted_password_database/{bin,backups,certs,data,docs,keys,logs}
    chmod -R 700  ${HOME}/.encrypted_password_database
fi

if [ ! -d ${HOME}/.encrypted_password_database ]; then
    echo "ERROR: Could not make directory ${HOME}/.encrypted_password_database"
    exit 1
fi

if [ ${RHEL_VERSION} -eq 0 ]; then
   echo "ERROR: Could not detect Red Hat release version"
   exit 1
fi

if [ ${RHEL_VERSION} -lt 7 ] || [ ${RHEL_VERSION} -gt 9 ]; then
    echo "INFO: Red Hat version ${RHEL_VERSION} is not supported for this release"
    exit 1
fi

echo "Red Hat version ${RHEL_VERSION}"

echo "Installing program files"
if [ ! -d ${HOME}/.encrypted_password_database/bin ]; then mkdir -pv  ${HOME}/.encrypted_password_database/bin; fi
/bin/cp -fv rhel${RHEL_VERSION}/encrypted_password_database ${HOME}/.encrypted_password_database/bin/.
chmod 755 ${HOME}/.encrypted_password_database/bin/encrypted_password_database

if [ ! -f ${HOME}/.encrypted_password_database/bin/encrypted_password_database ]; then
    echo "ERROR: Missing binary for application ${HOME}/.encrypted_password_database/bin/encrypted_password_database"
    exit 1
fi

echo "Installing Desktop files"
/bin/mkdir -pv ${HOME}/.local/share/applications
/bin/mkdir -pv ${HOME}/.local/share/icons
/bin/cp -fpv common/encrypted_password_database.desktop ${HOME}/.local/share/applications
chmod 755 ${HOME}/.local/share/applications/encrypted_password_database.desktop
/bin/cp -fv common/encrypted_password_database.png ${HOME}/.local/share/icons/.
chmod 644 ${HOME}/.local/share/icons//encrypted_password_database.png
sed -i s,'${HOME}',"${HOME}",g ${HOME}/.local/share/applications/encrypted_password_database.desktop

/bin/cp -fpv ${HOME}/.local/share/applications/encrypted_password_database.desktop ${HOME}/Desktop/.

echo "Install complete"
exit 0;
